import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_cloudformation
import aws_cdk.aws_iam
import aws_cdk.aws_lambda
import aws_cdk.aws_logs
import aws_cdk.aws_sns
import aws_cdk.core
import constructs

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/custom-resources", "1.38.0", __name__[0:-6], "custom-resources@1.38.0.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
